==> ParaView-v5.1.2.tar.gz: ParaView-v5.1.2/CoProcessing/TestDriver/vtkCPNodalFieldBuilder.h <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkCPNodalFieldBuilder.h

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkCPNodalFieldBuilder - Class for specifying nodal fields over grids.
// .SECTION Description
// Class for specifying nodal fields over grids for a test driver.  

#ifndef vtkCPNodalFieldBuilder_h
#define vtkCPNodalFieldBuilder_h

#include "vtkCPFieldBuilder.h"
#include "vtkPVCatalystTestDriverModule.h" // needed for export macros

class VTKPVCATALYSTTESTDRIVER_EXPORT vtkCPNodalFieldBuilder : public vtkCPFieldBuilder
{
public:
  static vtkCPNodalFieldBuilder * New();
  vtkTypeMacro(vtkCPNodalFieldBuilder, vtkCPFieldBuilder);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Return a field on Grid. 
  virtual void BuildField(unsigned long timeStep, double time,
                          vtkDataSet* grid);

protected:
  vtkCPNodalFieldBuilder();
  ~vtkCPNodalFieldBuilder();

private:
  vtkCPNodalFieldBuilder(const vtkCPNodalFieldBuilder&); // Not implemented
  void operator=(const vtkCPNodalFieldBuilder&); // Not implemented
};

#endif

==> ParaView-v5.2.0.tar.gz: ParaView-v5.2.0/CoProcessing/TestDriver/vtkCPNodalFieldBuilder.h <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkCPNodalFieldBuilder.h

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
/**
 * @class   vtkCPNodalFieldBuilder
 * @brief   Class for specifying nodal fields over grids.
 *
 * Class for specifying nodal fields over grids for a test driver.
*/

#ifndef vtkCPNodalFieldBuilder_h
#define vtkCPNodalFieldBuilder_h

#include "vtkCPFieldBuilder.h"
#include "vtkPVCatalystTestDriverModule.h" // needed for export macros

class VTKPVCATALYSTTESTDRIVER_EXPORT vtkCPNodalFieldBuilder : public vtkCPFieldBuilder
{
public:
  static vtkCPNodalFieldBuilder* New();
  vtkTypeMacro(vtkCPNodalFieldBuilder, vtkCPFieldBuilder);
  void PrintSelf(ostream& os, vtkIndent indent);

  /**
   * Return a field on Grid.
   */
  virtual void BuildField(unsigned long timeStep, double time, vtkDataSet* grid);

protected:
  vtkCPNodalFieldBuilder();
  ~vtkCPNodalFieldBuilder();

private:
  vtkCPNodalFieldBuilder(const vtkCPNodalFieldBuilder&) VTK_DELETE_FUNCTION;
  void operator=(const vtkCPNodalFieldBuilder&) VTK_DELETE_FUNCTION;
};

#endif
